{
    "$graph": [
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "EnvVarRequirement",
                    "envDef": [
                        {
                            "envName": "PATH",
                            "envValue": "/usr/local/bin/:/usr/bin:/bin"
                        }
                    ],
                    "id": "#envvar-global.yml"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "scidap/gatk:v3.5",
                    "dockerFile": "#################################################################\n# Dockerfile\n#\n# Software:         GATK\n# Software Version: 3.5\n# Description:      GATK image for SciDAP\n# Website:          http://scidap.com/\n# Provides:         GATK|bwa|picard\n\n# Base Image:       scidap/scidap:v0.0.1\n#################################################################\n\n### Base Image\nFROM scidap/scidap:v0.0.1\nMAINTAINER Andrey V Kartashov \"porter@porter.st\"\nENV DEBIAN_FRONTEND noninteractive\n\n################## BEGIN INSTALLATION ######################\n\nWORKDIR /tmp\n\n### Install required packages (samtools)\n\nRUN apt-get clean all &&\\\n    apt-get update &&\\\n    apt-get install -y --no-install-recommends \\\n        libncurses5-dev \\\n        bzip2 \\\n        zlib1g-dev \\\n        libncursesw5-dev \\\n        openjdk-7-jdk \\\n        maven && \\\n    apt-get clean && \\\n    apt-get purge && \\\n    rm -rf /var/lib/apt/lists/* /tmp/* /var/tmp/* /usr/share/doc/*\n\n\n### Installing BWA\n\nENV VERSION 0.7.12\nENV NAME bwa\nENV URL \"https://github.com/lh3/bwa/archive/${VERSION}.tar.gz\"\n\nRUN wget -q -O - $URL | tar -zxv && \\\n    cd ${NAME}-${VERSION} && \\\n    make -j 4 && \\\n    cd .. && \\\n    cp ./${NAME}-${VERSION}/${NAME} /usr/local/bin/ && \\\n    strip /usr/local/bin/${NAME}; true && \\\n    rm -rf ./${NAME}-${VERSION}/\n\n\n### Installing samtools/htslib/tabix/bgzip\n\nENV VERSIONH 1.2.1\nENV NAMEH htslib\nENV URLH \"https://github.com/samtools/htslib/archive/${VERSIONH}.tar.gz\"\n\nENV VERSION \"1.2\"\nENV NAME \"samtools\"\nENV URL \"https://github.com/samtools/samtools/archive/${VERSION}.tar.gz\"\n\nRUN wget -q -O - $URLH | tar -zxv && \\\n    cd ${NAMEH}-${VERSIONH} && \\\n    make -j 4 && \\\n    cd .. && \\\n    cp ./${NAMEH}-${VERSIONH}/tabix /usr/local/bin/ && \\\n    cp ./${NAMEH}-${VERSIONH}/bgzip /usr/local/bin/ && \\\n    cp ./${NAMEH}-${VERSIONH}/htsfile /usr/local/bin/ && \\\n    strip /usr/local/bin/tabix; true && \\\n    strip /usr/local/bin/bgzip; true && \\\n    strip /usr/local/bin/htsfile; true && \\\n    ln -s ./${NAMEH}-${VERSIONH}/ ./${NAMEH} && \\\n    wget -q -O - $URL | tar -zxv && \\\n    cd ${NAME}-${VERSION} && \\\n    make -j 4 && \\\n    cd .. && \\\n    cp ./${NAME}-${VERSION}/${NAME} /usr/local/bin/ && \\\n    strip /usr/local/bin/${NAME}; true && \\\n    rm -rf ./${NAMEH}-${VERSIONH}/ && \\\n    rm -rf ./${NAME}-${VERSION}/\n\n\n\n### INSTALL PICARD\n\nENV VERSION \"1.141\"\nENV NAME \"picard-tools\"\nENV ZIP ${NAME}-${VERSION}.zip\nENV URL https://github.com/broadinstitute/picard/releases/download/${VERSION}/${ZIP}\n\nRUN wget -q $URL -O ${ZIP} && \\\n    unzip $ZIP && \\\n    rm $ZIP && \\\n    cd ${NAME}-${VERSION} && \\\n    mv * /usr/local/bin && \\\n    cd .. && \\\n    bash -c 'echo -e \"#!/bin/bash\\njava -jar /usr/local/bin/picard.jar \\$@\" > /usr/local/bin/picard' && \\\n    chmod +x /usr/local/bin/picard && \\\n    rm -rf ${NAME}-${VERSION}\n\n\n### INSTALL GATK\n\nENV VERSION \"3.5\"\nENV NAME \"gatk-protected\"\nENV URL https://github.com/broadgsa/gatk-protected/archive/${VERSION}.tar.gz\n\nENV JAVA_HOME /usr/lib/jvm/java-7-openjdk-amd64/\nENV PATH /usr/lib/jvm/java-7-openjdk-amd64/bin:/usr/local/bin:$PATH\n\nRUN wget -q -O - $URL | tar -zxv --strip-components=1 && \\\n    grep -v \"oracle.jrockit.jfr.StringConstantPool\" /tmp/public/gatk-tools-public/src/main/java/org/broadinstitute/gatk/tools/walkers/varianteval/VariantEval.java >/tmp/public/gatk-tools-public/src/main/java/org/broadinstitute/gatk/tools/walkers/varianteval/VariantEval.1.java && \\\n    mv -f /tmp/public/gatk-tools-public/src/main/java/org/broadinstitute/gatk/tools/walkers/varianteval/VariantEval.1.java /tmp/public/gatk-tools-public/src/main/java/org/broadinstitute/gatk/tools/walkers/varianteval/VariantEval.java && \\\n    mvn verify -Ddisable.shadepackage '-P!queue' && \\\n    cd ./target/executable/ && \\\n    cp -r ./ /usr/local/bin/ && \\\n    cd /tmp && \\\n    rm -rf ./* && \\\n    bash -c 'echo -e \"#!/bin/bash\\njava -jar /usr/local/bin/GenomeAnalysisTK.jar  \\$@\" > /usr/local/bin/GenomeAnalysisTK' && \\\n    chmod +x /usr/local/bin/GenomeAnalysisTK\n",
                    "id": "#GATK-docker.yml"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "-Xmx8g",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#GATK-ApplyRecalibration.cwl/java_mem"
                },
                {
                    "type": "string",
                    "default": "-Djava.io.tmpdir=/tmp",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#GATK-ApplyRecalibration.cwl/java_tmp"
                },
                {
                    "type": "string",
                    "default": "SNP",
                    "inputBinding": {
                        "position": 11,
                        "prefix": "-mode"
                    },
                    "doc": "specify if VQSR is called on SNPs or Indels",
                    "id": "#GATK-ApplyRecalibration.cwl/mode"
                },
                {
                    "type": "int",
                    "default": 4,
                    "inputBinding": {
                        "position": 12,
                        "prefix": "-nt"
                    },
                    "doc": "multithreading option",
                    "id": "#GATK-ApplyRecalibration.cwl/multithreading_nt"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-input"
                    },
                    "doc": "input vcf File raw variant calls from haplotype caller",
                    "id": "#GATK-ApplyRecalibration.cwl/raw_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-recalFile"
                    },
                    "doc": "the recal file generated by VariantRecalibrator",
                    "id": "#GATK-ApplyRecalibration.cwl/recal_file"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-R"
                    },
                    "doc": "reference genome",
                    "id": "#GATK-ApplyRecalibration.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 8,
                        "prefix": "-tranchesFile"
                    },
                    "doc": "the tranches file generated by VariantRecalibrator",
                    "id": "#GATK-ApplyRecalibration.cwl/tranches_file"
                },
                {
                    "type": "float",
                    "default": 99.9,
                    "inputBinding": {
                        "position": 10,
                        "prefix": "--ts_filter_level"
                    },
                    "doc": "filtering level default value is 99.9",
                    "id": "#GATK-ApplyRecalibration.cwl/ts_filter_level"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "./test/test-files",
                    "position": 2,
                    "separate": false,
                    "prefix": "-Djava.io.tmpdir="
                },
                {
                    "valueFrom": "/usr/local/bin/GenomeAnalysisTK.jar",
                    "position": 3,
                    "prefix": "-jar"
                },
                {
                    "valueFrom": "ApplyRecalibration",
                    "position": 4,
                    "prefix": "-T"
                },
                {
                    "valueFrom": "$(inputs.raw_vcf.path.replace(/^.*[\\\\\\/]/, \"\").replace(/\\.[^/.]+$/, \"\") + \".\" + inputs.mode + \".vqsr.vcf\")",
                    "position": 9,
                    "prefix": "-o"
                }
            ],
            "baseCommand": [
                "java"
            ],
            "id": "#GATK-ApplyRecalibration.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.vqsr.vcf"
                    },
                    "doc": "The output recalibration VCF file",
                    "id": "#GATK-ApplyRecalibration.cwl/vqsr_vcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "doc": "GATK-VariantsRecalibrator.cwl is developed for CWL consortium\n\nUsage:\n```\njava -Xmx8G \\\n      -jar gatk.jar\n      -T VariantRecalibrator \\\n      -R [reference_fasta] \\\n      -recalFile    $tmpDir/out.recal \\\n      -tranchesFile $tmpDir/out.tranches \\\n      -rscriptFile  $tmpDir/out.R \\\n      -nt 4 \\\n      -an MQRankSum -an ReadPosRankSum -an DP -an FS -an QD \\\n      -mode SNP \\\n      -resource:hapmap,known=false,training=true,truth=true,prior=15.0 [hapmap_vcf] \\\n      -resource:dbsnp,known=true,training=false,truth=false,prior=2.0  [dbsnp_vcf] \\\n      -resource:omni,known=false,training=true,truth=true,prior=12.0   [1komni_vcf] \\\n      -resource:1000G,known=false,training=true,truth=false,prior=10.0 [1ksnp_vcf]\n```\n",
            "hints": [
                {
                    "$import": "#envvar-global.yml"
                },
                {
                    "$import": "#GATK-docker.yml"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-input"
                    },
                    "doc": "input vcf File raw variant calls from haplotype caller",
                    "id": "#GATK-VariantRecalibrator-SNPs.cwl/haplotypecaller_snps_vcf"
                },
                {
                    "type": "string",
                    "default": "-Xmx8g",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#GATK-VariantRecalibrator-SNPs.cwl/java_arg"
                },
                {
                    "type": "string",
                    "default": "-Djava.io.tmpdir=/tmp",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#GATK-VariantRecalibrator-SNPs.cwl/java_tmp"
                },
                {
                    "type": "int",
                    "default": 4,
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-nt"
                    },
                    "doc": "multithreading option",
                    "id": "#GATK-VariantRecalibrator-SNPs.cwl/multithreading_nt"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-R"
                    },
                    "doc": "reference genome",
                    "id": "#GATK-VariantRecalibrator-SNPs.cwl/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "-resource:dbsnp,known=true,training=false,truth=false,prior=8.0"
                    },
                    "doc": "dbSNP  reference data",
                    "id": "#GATK-VariantRecalibrator-SNPs.cwl/resource_dbsnp"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "-resource:hapmap,known=false,training=true,truth=true,prior=15.0"
                    },
                    "doc": "hapmap reference data",
                    "id": "#GATK-VariantRecalibrator-SNPs.cwl/resource_hapmap"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "-resource:omni,known=false,training=true,truth=false,prior=12.0"
                    },
                    "doc": "omni reference data",
                    "id": "#GATK-VariantRecalibrator-SNPs.cwl/resource_omni"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "vqsr_recal.snps.recal"
                    },
                    "doc": "the recal File",
                    "id": "#GATK-VariantRecalibrator-SNPs.cwl/recal_File"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "vqsr_tranches.snps.recal"
                    },
                    "doc": "the tranches File",
                    "id": "#GATK-VariantRecalibrator-SNPs.cwl/tranches_File"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "/usr/local/bin/GenomeAnalysisTK.jar",
                    "position": 3,
                    "prefix": "-jar"
                },
                {
                    "valueFrom": "VariantRecalibrator",
                    "position": 4,
                    "prefix": "-T"
                },
                {
                    "valueFrom": "SNP",
                    "position": 12,
                    "prefix": "-mode"
                },
                {
                    "valueFrom": "QD",
                    "position": 13,
                    "prefix": "-an"
                },
                {
                    "valueFrom": "MQRankSum",
                    "position": 13,
                    "prefix": "-an"
                },
                {
                    "valueFrom": "ReadPosRankSum",
                    "position": 13,
                    "prefix": "-an"
                },
                {
                    "valueFrom": "FS",
                    "position": 13,
                    "prefix": "-an"
                },
                {
                    "valueFrom": "MQ",
                    "position": 13,
                    "prefix": "-an"
                },
                {
                    "valueFrom": "vqsr_tranches.snps.recal",
                    "position": 14,
                    "prefix": "-tranchesFile"
                },
                {
                    "valueFrom": "vqsr_recal.snps.recal",
                    "position": 15,
                    "prefix": "-recalFile"
                },
                {
                    "valueFrom": "vqsr_tranches.snps.plots.R",
                    "position": 16,
                    "prefix": "-rscriptFile"
                }
            ],
            "baseCommand": [
                "java"
            ],
            "id": "#GATK-VariantRecalibrator-SNPs.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/snpeff:4.3",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-csvStats",
                        "position": 3
                    },
                    "id": "#snpEff.cwl/csvStats"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-dataDir",
                        "position": 1
                    },
                    "id": "#snpEff.cwl/data_dir"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 7
                    },
                    "id": "#snpEff.cwl/genome"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-noStats",
                        "position": 2
                    },
                    "id": "#snpEff.cwl/no_stats"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-nodownload",
                        "position": 5
                    },
                    "id": "#snpEff.cwl/nodownload"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#snpEff.cwl/output_format/vcf",
                            "#snpEff.cwl/output_format/gatk",
                            "#snpEff.cwl/output_format/bed",
                            "#snpEff.cwl/output_format/bedAnn"
                        ]
                    },
                    "default": "vcf",
                    "inputBinding": {
                        "prefix": "-o",
                        "position": 4
                    },
                    "id": "#snpEff.cwl/output_format"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 8
                    },
                    "id": "#snpEff.cwl/variant_calling_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-v",
                        "position": 6
                    },
                    "id": "#snpEff.cwl/verbose"
                }
            ],
            "stdout": "$(inputs.variant_calling_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.ann.vcf')",
            "outputs": [
                {
                    "type": "File",
                    "id": "#snpEff.cwl/annotated_vcf",
                    "outputBinding": {
                        "glob": "$(inputs.variant_calling_file.path.replace(/^.*[\\\\\\/]/, '').replace(/\\.[^/.]+$/, '') + '.ann.vcf')"
                    }
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "snpEff_summary.html"
                    },
                    "id": "#snpEff.cwl/summary_html"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "snpEff_genes.txt"
                    },
                    "id": "#snpEff.cwl/summary_txt"
                }
            ],
            "baseCommand": [
                "snpEff"
            ],
            "arguments": [
                "ann",
                "-stats",
                "snpEff_summary.html"
            ],
            "id": "#snpEff.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/haplotest_vcf"
                },
                {
                    "type": "string",
                    "default": "INDEL",
                    "id": "#main/indel_mode"
                },
                {
                    "type": "File",
                    "doc": "reference human genome file",
                    "id": "#main/reference"
                },
                {
                    "type": "File",
                    "id": "#main/resource_dbsnp"
                },
                {
                    "type": "File",
                    "id": "#main/resource_hapmap"
                },
                {
                    "type": "File",
                    "id": "#main/resource_mills"
                },
                {
                    "type": "File",
                    "id": "#main/resource_omni"
                },
                {
                    "type": "string",
                    "default": "SNP",
                    "id": "#main/snp_mode"
                },
                {
                    "type": "Directory",
                    "id": "#main/snpf_data_dir"
                },
                {
                    "type": "string",
                    "id": "#main/snpf_genome"
                },
                {
                    "type": "boolean",
                    "id": "#main/snpf_nodownload"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/snpeff_snps/annotated_vcf",
                    "id": "#main/annotated_snps"
                },
                {
                    "type": "File",
                    "outputSource": "#main/vqsr_snps/recal_File",
                    "id": "#main/recal_File"
                }
            ],
            "steps": [
                {
                    "run": "#GATK-ApplyRecalibration.cwl",
                    "in": [
                        {
                            "source": "#main/snp_mode",
                            "id": "#main/apply_recalibration_snps/mode"
                        },
                        {
                            "source": "#main/haplotest_vcf",
                            "id": "#main/apply_recalibration_snps/raw_vcf"
                        },
                        {
                            "source": "#main/vqsr_snps/recal_File",
                            "id": "#main/apply_recalibration_snps/recal_file"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/apply_recalibration_snps/reference"
                        },
                        {
                            "source": "#main/vqsr_snps/tranches_File",
                            "id": "#main/apply_recalibration_snps/tranches_file"
                        }
                    ],
                    "out": [
                        "#main/apply_recalibration_snps/vqsr_vcf"
                    ],
                    "id": "#main/apply_recalibration_snps"
                },
                {
                    "run": "#snpEff.cwl",
                    "in": [
                        {
                            "source": "#main/snpf_data_dir",
                            "id": "#main/snpeff_snps/data_dir"
                        },
                        {
                            "source": "#main/snpf_genome",
                            "id": "#main/snpeff_snps/genome"
                        },
                        {
                            "source": "#main/snpf_nodownload",
                            "id": "#main/snpeff_snps/nodownload"
                        },
                        {
                            "source": "#main/apply_recalibration_snps/vqsr_vcf",
                            "id": "#main/snpeff_snps/variant_calling_file"
                        }
                    ],
                    "out": [
                        "#main/snpeff_snps/annotated_vcf"
                    ],
                    "id": "#main/snpeff_snps"
                },
                {
                    "run": "#GATK-VariantRecalibrator-SNPs.cwl",
                    "in": [
                        {
                            "source": "#main/haplotest_vcf",
                            "id": "#main/vqsr_snps/haplotypecaller_snps_vcf"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/vqsr_snps/reference"
                        },
                        {
                            "source": "#main/resource_dbsnp",
                            "id": "#main/vqsr_snps/resource_dbsnp"
                        },
                        {
                            "source": "#main/resource_hapmap",
                            "id": "#main/vqsr_snps/resource_hapmap"
                        },
                        {
                            "source": "#main/resource_omni",
                            "id": "#main/vqsr_snps/resource_omni"
                        }
                    ],
                    "out": [
                        "#main/vqsr_snps/tranches_File",
                        "#main/vqsr_snps/recal_File"
                    ],
                    "id": "#main/vqsr_snps"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
